%% Kidney Functioning in Human Leptin Metabolism
% This program uses the Lineweaver-Burk analysis and linear least-sqaures
% regression to estimate the Michaelis Menten Parameters and associated
% confidence intervals.
clear all

%% Data for linear least-squares regression
%Plasma leptin concentration
S = [0.75; 1.18; 1.47; 1.61; 1.64; 5.26; 5.88; 6.25; 8.33; 10.0;11.11; ...
    20.0; 21.74; 25.0; 27.77; 35.71];
% Renal Leptin Uptake
R = [0.11; 0.204; 0.22; 0.143; 0.35; 0.48; 0.37; 0.48; 0.83; 1.25; 0.56; ...
    3.33; 2.5; 2.0; 1.81; 1.67]; 

%% Lineweaver-Burk Plot using Linear Least-Squares Regression
x = 1./S;
%The coefficient matrix
A = [x ones(16,1)];
%The constants vector
y = 1./R;
%Performing linear least squares regression via the normal equations
c = (A'*A)\A'*y

figure;
plot(x, y,'ko','LineWidth',2)

ylabel('\fontname{Arial}1/{\itR} in min/nmol','FontSize',18)
xlabel('\fontname{Arial} 1/{\itS} in ml/ng','FontSize',18)
set(gca,'FontSize',16,'LineWidth',2)

hold on
%Plotting the fitted Lineweaver-Burk Plot
yhat = A*c;
plot(x,yhat,'k-','LineWidth',2)

%% Quantifying the goodness of fit and SD
hold on 
%residual
r = y - yhat; 
% sum of the squared residuals
SSR = sum(r.^2) 
% coefficient of determination
R2 = 1 - SSR/sum((y - mean(y)).^2)
%residual variance
s2y = 1/(length(S) - length(c))*SSR
%residual standard deviation
sy = sqrt(s2y);

%% Plotting the 95% Interval for Variability in Y data
yplus2SD = yhat + 2.145*sy;
yminus2SD = yhat - 2.145*sy;
plot(x,yplus2SD, 'k--',x,yminus2SD, 'k--','LineWidth',2)

l = legend('Data points: 1/{\itR}','Fitted linear curve','95% confidence interval');
set(l,'FontSize',14)

%% Estimating errors in model parameters
m = length(S);
n = length(c);
K = (A'*A)\A';
K2 = K.^2 
% Variances
for i = 1:n
    s2yc(i) = sum(K2(i,:))*s2y
end
% Covariance
    s2yc12 = K(1,:)*K(2,:)'
    s2yc12 = s2yc12*s2y
    
%% Error in model predictions
x_m = [0.03; 0.1; 0.25; 0.5; 0.75; 1.0; 1.3]; %independent vairable vector
A_m = [x_m ones(length(x_m),1)];
s2yhat = s2y*diag(A_m*K*K'*A_m'); % variance associated with y predictions
syhat = sqrt(s2yhat); %standard deviation or error

%Plotting the fitted model with confidence interval describing error in
%model predictions
y_mhat = A_m*c;
figure; 
plot(x_m,y_mhat,'k-',x_m, y_mhat + syhat,'k--',x_m, y_mhat - syhat,'k--', ...
    'LineWidth',2)
ylabel('\fontname{Arial}1/{\itR} in min/nmol','FontSize',18)
xlabel('\fontname{Arial} 1/{\itS} in ml/ng','FontSize',18)
set(gca,'FontSize',16,'LineWidth',2)

l = legend('Model predictions','1{\it\sigma} error curves');
set(l,'FontSize',14)