function alpha = steepestparabolicinterpolation(func, ab, tolx, x, df)
% Successive parabolic interpolation is used to find the minimum
% of a unimodal function.

% Input variables
% func: nonlinear function to be minimized
% ab  : initial bracketing interval [a, b]
% tolx: tolerance in estimating the minimum
% x   : guess point
% df  : gradient vector evaluated at x

% Other variables
k = 0; % counter
maxloops = 20;

% Set of three points to construct the parabola
x0 = ab(1);
x2 = ab(2);
x1 = (x0 + x2)/2;

% Function values at the three points
fx0 = feval(func, x0, x, df);
fx1 = feval(func, x1, x, df);
fx2 = feval(func, x2, x, df);

% Iterative solution
while (x2 - x0) > tolx
    % Calculate minimum point of parabola
    numerator = (x2^2 - x1^2)*fx0 - (x2^2 - x0^2)*fx1 + (x1^2 - x0^2)*fx2;
    denominator = 2*((x2 - x1)*fx0 - (x2 - x0)*fx1 + (x1 - x0)*fx2);
    xmin = numerator/denominator;
    
    % Function value at xmin
    fxmin = feval(func, xmin, x, df);
    
    % Select set of three points to construct new parabola
    if xmin < x1
        if fxmin < fx1
            x2 = x1;
            fx2 = fx1;
            x1 = xmin;
            fx1 = fxmin;
        else
            x0 = xmin;
            fx0 = fxmin;
        end
    else
        if fxmin < fx1
            x0 = x1;
            fx0 = fx1;
            x1 = xmin;
            fx1 = fxmin;
        else
            x2 = xmin;
            fx2 = fxmin;
        end
    end
    k = k + 1;
    if k > maxloops
        break
    end
end
alpha = xmin;
fprintf('x0 = %7.6f x2 = %7.6f f(x0) = %7.6f f(x2) = %7.6f \n', x0, x2, fx0, fx2)
fprintf('x_min = %7.6f f(x_min) = %7.6f \n',xmin, fxmin)
fprintf('number of parabolic interpolation iterations = %2d \n', k)